# DESCRIPTION: Example perl module that just "works"
#
# Copyright 2007-2009 by Wilson Snyder.  This program is free software; you
# can redistribute it and/or modify it under the terms of either the GNU
# Lesser General Public License Version 3 or the Perl Artistic License
# Version 2.0.
######################################################################

package Stub;

print "ok: in package Stub\n";

######################################################################
1;
